@@ -156,3 +156,17 @@ class AzureAPI(BaseMicrosoftAPI):
                   f'workspaces?api-version=2018-04-01'
             databricks_workspaces += self.call_api(url)
         return databricks_workspaces
+
+    def list_factories(self, subscriptions=None):
+        if subscriptions is None:
+            if self.subscriptions is None:
+                self.subscriptions = self.subscriptionIds()
+            subscriptions = self.subscriptions
+
+        factories = []
+        for subscription in subscriptions:
+            url = f'https://management.azure.com/subscriptions/{subscription}'\
+                  f'/providers/Microsoft.DataFactory/'\
+                  f'factories?api-version=2018-06-01'
+            factories += self.call_api(url)
+        return factories
